@@ -20,10 +20,10 @@
 #include <string.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <libebook/e-book.h>
 
 #include "contacts-defs.h"
+#include "contacts-ui.h"
 #include "contacts-utils.h"
 #include "contacts-main.h"
 
@@ -31,21 +31,17 @@ void
 contacts_added_cb (EBookView *book_view, const GList *contacts,
 		   ContactsData *data)
 {
-	GtkComboBox *groups_combobox;
 	GtkListStore *model;
 	GtkTreeModelFilter *filter;
 	GList *c;
-	GladeXML *xml = data->xml;
 	GtkWidget *widget;
 	GHashTable *contacts_table = data->contacts_table;
 
-	/* Get TreeView model and combo box to add contacts/groups */
-	widget = glade_xml_get_widget (xml, "contacts_treeview");
+	/* Get TreeView model and combo box to add contacts */
+	widget = data->ui->contacts_treeview;
 	filter = GTK_TREE_MODEL_FILTER (gtk_tree_view_get_model 
 				 	(GTK_TREE_VIEW (widget)));
 	model = GTK_LIST_STORE (gtk_tree_model_filter_get_model (filter));
-	groups_combobox = GTK_COMBO_BOX (glade_xml_get_widget 
-					 (xml, "groups_combobox"));
 
 	/* Iterate over new contacts and add them to the list */
 	for (c = (GList *)contacts; c; c = c->next) {
@@ -71,7 +67,7 @@ contacts_added_cb (EBookView *book_view, const GList *contacts,
 			name = "Unnamed";
 		uid = e_contact_get_const (contact, E_CONTACT_UID);
 		hash->contact = g_object_ref (contact);
-		hash->xml = xml;
+		hash->contacts_data = data;
 		g_hash_table_insert (contacts_table, (gchar *)uid, hash);
 
 		gtk_list_store_insert_with_values (model, &hash->iter, 0,
@@ -87,14 +83,13 @@ contacts_added_cb (EBookView *book_view, const GList *contacts,
 			GList *group;
 			for (group = contact_groups; group;
 			     group = group->next) {
-				if (!g_list_find_custom (data->contacts_groups, 
+				if (!g_list_find_custom (data->contacts_groups,
 							 group->data,
 							 (GCompareFunc) strcmp))
 				{
-					gtk_combo_box_append_text
-					    (groups_combobox, group->data);
-					data->contacts_groups = g_list_prepend 
+					data->contacts_groups = g_list_prepend
 					   (data->contacts_groups, group->data);
+					contacts_ui_update_groups_list (data);
 				}
 			}
 			g_list_free (contact_groups);
@@ -102,7 +97,7 @@ contacts_added_cb (EBookView *book_view, const GList *contacts,
 	}
 	
 	/* Update view */
-	contacts_update_treeview (widget);
+	contacts_update_treeview (data);
 }
 
 void
@@ -112,18 +107,15 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts,
 	GList *c;
 	GtkWidget *widget;
 	GtkListStore *model;
-	GtkComboBox *groups_combobox;
-	GladeXML *xml = data->xml;
-	EContact *current_contact = contacts_get_selected_contact (data->xml,
+
+	EContact *current_contact = contacts_get_selected_contact (data,
 							data->contacts_table);
 	if (current_contact) g_object_ref (current_contact);
 
-	widget = glade_xml_get_widget (data->xml, "contacts_treeview");
+	widget = data->ui->contacts_treeview;
 	model = GTK_LIST_STORE (gtk_tree_model_filter_get_model 
 		 (GTK_TREE_MODEL_FILTER (gtk_tree_view_get_model 
 		  (GTK_TREE_VIEW (widget)))));
-	groups_combobox = GTK_COMBO_BOX (glade_xml_get_widget 
-					 (xml, "groups_combobox"));
 
 	/* Loop through changed contacts */	
 	for (c = (GList *)contacts; c; c = c->next) {
@@ -141,7 +133,7 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts,
 		/* Replace contact */
 /*		g_object_unref (hash->contact);*/
 		hash->contact = g_object_ref (contact);
-		hash->xml = data->xml;
+		hash->contacts_data = data;
 		g_hash_table_steal (data->contacts_table, uid);
 		g_hash_table_insert (data->contacts_table, (gchar *)uid, hash);
 
@@ -158,7 +150,7 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts,
 					(contact, E_CONTACT_UID),
 				    e_contact_get_const
 					(current_contact, E_CONTACT_UID)) == 0)
-				contacts_display_summary (contact, data->xml);
+				contacts_display_summary (contact, data);
 		}
 
 		/* Check for groups and add them to group list */
@@ -169,14 +161,13 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts,
 			GList *group;
 			for (group = contact_groups; group;
 			     group = group->next) {
-				if (!g_list_find_custom (data->contacts_groups, 
+				if (!g_list_find_custom (data->contacts_groups,
 							 group->data,
 							 (GCompareFunc) strcmp))
 				{
-					gtk_combo_box_append_text
-					    (groups_combobox, group->data);
 					data->contacts_groups = g_list_prepend 
 					   (data->contacts_groups, group->data);
+					contacts_ui_update_groups_list (data);
 				}
 			}
 			g_list_free (contact_groups);
@@ -186,7 +177,7 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts,
 	if (current_contact) g_object_unref (current_contact);
 
 	/* Update view */
-	contacts_update_treeview (widget);
+	contacts_update_treeview (data);
 }
 
 /* TODO: Remove groups that no longer contain contacts */
@@ -201,7 +192,26 @@ contacts_removed_cb (EBookView *book_view, const GList *ids, ContactsData *data)
 	}
 
 	/* Update view */
-	contacts_update_treeview (glade_xml_get_widget (data->xml,
-							"contacts_treeview"));
+	contacts_update_treeview (data);
 }
 
+void
+contacts_sequence_complete_cb (EBookView *book_view, const GList *ids, ContactsData *data)
+{
+	GtkTreeModelFilter *model;
+
+	model = GTK_TREE_MODEL_FILTER (data->contacts_filter);
+
+	/* If there's only one visible contact, select it */
+	if (data->initialising) {
+		GtkTreeSelection *selection =
+					gtk_tree_view_get_selection (GTK_TREE_VIEW (data->ui->contacts_treeview));
+		GtkTreeIter iter;
+		if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (model),
+						   &iter)) {
+			gtk_tree_selection_select_iter (selection, &iter);
+		}
+		data->initialising = FALSE;
+		gtk_tree_view_scroll_to_point (GTK_TREE_VIEW (data->ui->contacts_treeview), 0, 0);
+	}
+}
