@@ -20,7 +20,6 @@
 #include <string.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <libebook/e-book.h>
 #include "config.h"
 #ifdef HAVE_GNOMEVFS
@@ -29,11 +28,66 @@
 
 #include "contacts-defs.h"
 #include "contacts-utils.h"
+#include "contacts-ui.h"
 #include "contacts-callbacks-ui.h"
 #include "contacts-callbacks-ebook.h"
 #include "contacts-edit-pane.h"
 #include "contacts-main.h"
 
+void
+contacts_chooser_add_cb (GtkWidget *button, ContactsData *data)
+{
+	GtkWidget *treeview, *entry;
+	GtkListStore *model;
+	GtkTreeIter iter;
+	const gchar *text;
+	
+	entry = data->ui->chooser_entry;
+	text = gtk_entry_get_text (GTK_ENTRY (entry));
+	
+	if (g_utf8_strlen (text, -1) <= 0)
+		return;
+	
+	treeview = data->ui->chooser_treeview;
+	model = GTK_LIST_STORE (
+		gtk_tree_view_get_model (GTK_TREE_VIEW (treeview)));
+	
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter, CHOOSER_TICK_COL, TRUE,
+			    CHOOSER_NAME_COL, text, -1);
+	
+	gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+	contacts_ui_update_groups_list (data);
+}
+
+
+
+void
+contacts_search_changed_cb (GtkWidget *widget, ContactsData *data)
+{
+	gtk_widget_grab_focus (data->ui->search_entry);
+	contacts_update_treeview (data);
+}
+
+void
+contacts_chooser_toggle_cb (GtkCellRendererToggle * cell,
+		   gchar * path_string, gpointer user_data)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model = GTK_TREE_MODEL (user_data);
+
+	gtk_tree_model_get_iter_from_string (model, &iter, path_string);
+	if (gtk_cell_renderer_toggle_get_active (cell))
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+				    CHOOSER_TICK_COL, FALSE, -1);
+	else
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+				    CHOOSER_TICK_COL, TRUE, -1);
+}
+
+
+
 void
 contacts_selection_cb (GtkTreeSelection * selection, ContactsData *data)
 {
@@ -44,10 +98,10 @@ contacts_selection_cb (GtkTreeSelection * selection, ContactsData *data)
 	contact = contacts_contact_from_selection (selection,
 						   data->contacts_table);
 	if (contact) {
-		contacts_display_summary (contact, data->xml);
+		contacts_display_summary (contact, data);
 	} else {
-		contacts_set_available_options (data->xml, TRUE, FALSE, FALSE);
-		widget = glade_xml_get_widget (data->xml, "summary_vbox");
+		contacts_set_available_options (data, TRUE, FALSE, FALSE);
+		widget = data->ui->summary_vbox;
 		gtk_widget_hide (widget);
 	}
 }
@@ -63,10 +117,10 @@ void
 contacts_edit_cb (GtkWidget *source, ContactsData *data)
 {
 	/* Disable the new/edit/delete options and get the contact to edit */
-	data->contact = contacts_get_selected_contact (data->xml,
+	data->contact = contacts_get_selected_contact (data,
 						       data->contacts_table);
 	if (data->contact) {
-		contacts_set_available_options (data->xml, FALSE, FALSE, FALSE);
+		contacts_set_available_options (data, FALSE, FALSE, FALSE);
 		data->changed = FALSE;		
 		contacts_edit_pane_show (data, FALSE);
 	}
@@ -94,12 +148,12 @@ contacts_delete_cb (GtkWidget *source, ContactsData *data)
 	GtkWidget *widget;
 	GtkTreeSelection *selection;
 
-	widget = glade_xml_get_widget (data->xml, "contacts_treeview");
+	widget = data->ui->contacts_treeview;
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
 	count_selected = gtk_tree_selection_count_selected_rows (selection);
 
 	if (count_selected < 2) {
-		contact = contacts_get_selected_contact (data->xml,
+		contact = contacts_get_selected_contact (data,
 						data->contacts_table);
 		if (!contact) return;
 
@@ -130,7 +184,7 @@ contacts_delete_cb (GtkWidget *source, ContactsData *data)
 	}
 
 
-	main_window = glade_xml_get_widget (data->xml, "main_window");
+	main_window = data->ui->main_window;
 	dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
 					 0, GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_CANCEL,
@@ -189,8 +243,7 @@ contacts_import (ContactsData *data, const gchar *filename, gboolean do_confirm)
 					GtkWidget *dialog, *main_window;
 					GList *widgets;
 					
-					main_window = glade_xml_get_widget (
-						data->xml, "main_window");
+					main_window = data->ui->main_window;
 					dialog = gtk_message_dialog_new (
 						GTK_WINDOW (main_window),
 						0, GTK_MESSAGE_QUESTION,
@@ -229,9 +282,9 @@ contacts_import (ContactsData *data, const gchar *filename, gboolean do_confirm)
 					#endif
 					g_list_free (lcontact);
 				} else {
-					contacts_display_summary (contact, data->xml);
+					contacts_display_summary (contact, data);
 					contacts_set_available_options (
-						data->xml, TRUE, FALSE, FALSE);
+						data, TRUE, FALSE, FALSE);
 				}
 				g_object_unref (contact);
 			}
@@ -253,7 +306,7 @@ contacts_import_cb (GtkWidget *source, ContactsData *data)
 	GList *widgets;
 	GtkFileFilter *filter;
 	GtkWidget *main_window =
-		glade_xml_get_widget (data->xml, "main_window");
+		data->ui->main_window;
 	GtkWidget *dialog = gtk_file_chooser_dialog_new (
 		_("Import Contact"),
 		GTK_WINDOW (main_window),
@@ -321,7 +374,7 @@ contacts_export_cb (GtkWidget *source, ContactsData *data)
 {
 	GList *widgets;
 	GtkWidget *main_window =
-		glade_xml_get_widget (data->xml, "main_window");
+		data->ui->main_window;
 	GtkWidget *dialog = gtk_file_chooser_dialog_new (
 		_("Export Contact"),
 		GTK_WINDOW (main_window),
@@ -404,7 +457,7 @@ contacts_edit_menu_activate_cb (GtkWidget *widget, ContactsData *data)
 {
 	gboolean can_cutcopy, can_paste;
 
-	widget = glade_xml_get_widget (data->xml, "main_window");
+	widget = data->ui->main_window;
 	widget = gtk_window_get_focus (GTK_WINDOW (widget));
 	if ((GTK_IS_EDITABLE (widget) || GTK_IS_TEXT_VIEW (widget) || GTK_IS_LABEL (widget)))
 	{
@@ -428,11 +481,11 @@ contacts_edit_menu_activate_cb (GtkWidget *widget, ContactsData *data)
 	else
 		can_cutcopy = can_paste = FALSE;
 
-	widget = glade_xml_get_widget (data->xml, "cut");
+	widget = data->ui->cut_menuitem;
 	gtk_widget_set_sensitive (widget, can_cutcopy);
-	widget = glade_xml_get_widget (data->xml, "copy");
+	widget = data->ui->copy_menuitem;
 	gtk_widget_set_sensitive (widget, can_cutcopy);
-	widget = glade_xml_get_widget (data->xml, "paste");
+	widget = data->ui->paste_menuitem;
 	gtk_widget_set_sensitive (widget, can_paste);
 }
 
@@ -544,46 +597,46 @@ contacts_is_row_visible_cb (GtkTreeModel * model, GtkTreeIter * iter,
 			    GHashTable *contacts_table)
 {
 	gboolean result = FALSE;
-	gchar *group;
+	gchar *group = NULL;
 	GList *groups, *g;
 	const gchar *uid;
 	EContactListHash *hash;
-	GtkComboBox *groups_combobox;
 	const gchar *search_string;
-	GladeXML *xml;
+	ContactsData *data;
 
 	/* Check if the contact is in the currently selected group. */
 	gtk_tree_model_get (model, iter, CONTACT_UID_COL, &uid, -1);
 	if (!uid) return FALSE;
 	hash = g_hash_table_lookup (contacts_table, uid);
 	if (!hash || !hash->contact) return FALSE;
-	xml = hash->xml;
-	groups_combobox = GTK_COMBO_BOX (glade_xml_get_widget 
-					 (xml, "groups_combobox"));
-	group = gtk_combo_box_get_active_text (groups_combobox);
-	groups = e_contact_get (hash->contact, E_CONTACT_CATEGORY_LIST);
-	if (gtk_combo_box_get_active (groups_combobox) > 0) {
-		for (g = groups; g; g = g->next) {
-			if (strcmp (group, g->data) == 0)
-				result = TRUE;
-			g_free (g->data);
-		}
-		if (groups)
-			g_list_free (groups);
-	} else
+	data = hash->contacts_data;
+
+	if (data->selected_group && strcmp ("All", data->selected_group))
+	{
+		groups = e_contact_get (hash->contact, E_CONTACT_CATEGORY_LIST);
+		if ((group = data->selected_group)) {
+			for (g = groups; g; g = g->next) {
+				if (strcmp (group, g->data) == 0)
+					result = TRUE;
+				g_free (g->data);
+			}
+			if (groups)
+				g_list_free (groups);
+		} else
+			result = TRUE;
+		if (!result)
+			return FALSE;
+	}
+	else
 		result = TRUE;
-	g_free (group);
-	if (!result)
-		return FALSE;
 
 	/* Search for any occurrence of the string in the search box in the 
 	 * contact file-as name; if none is found, row isn't visible. Ignores 
 	 * empty searches.
 	 */
-	if (GTK_WIDGET_VISIBLE (glade_xml_get_widget (
-	    xml, "search_entry_hbox"))) {
+	if (GTK_WIDGET_VISIBLE (data->ui->search_entry)) {
 		search_string = gtk_entry_get_text (
-			GTK_ENTRY (glade_xml_get_widget (xml, "search_entry")));
+			GTK_ENTRY (data->ui->search_entry));
 		if ((search_string) &&
 		    (g_utf8_strlen (search_string, -1) > 0)) {
 			gchar *name_string;
@@ -599,13 +652,12 @@ contacts_is_row_visible_cb (GtkTreeModel * model, GtkTreeIter * iter,
 				g_free (isearch);
 			}
 		}
-	} else {
+	} else if ((data->ui->symbols_radiobutton)){
 		gint i;
 		gchar *name, *uname;
 		gunichar c;
 		GSList *b, *buttons = gtk_radio_button_get_group (
-			GTK_RADIO_BUTTON (glade_xml_get_widget (
-				xml, "symbols_radiobutton")));
+			GTK_RADIO_BUTTON (data->ui->symbols_radiobutton));
 		
 		/* Find the active radio button */
 		for (b = buttons, i = 0; b; b = b->next, i++)
